/*! jwt-auth-react v3.2.5 | Apache-2.0 Copyright (2020) Arkadip Bhattacharya */
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactRouterDom = require('react-router-dom');

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/**
 * Initialized Auth Context
 */
var Auth = React__default.createContext(null);
var AuthContextProvider = Auth.Provider;
var AuthContext = Auth;

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/**
 * Token Object
 */
var TokenObject = /** @class */ (function () {
    function TokenObject(tokenName) {
        this.tokenName = tokenName;
    }
    TokenObject.prototype.isTokenExpire = function () {
        var _e = JSON.parse(localStorage[this.tokenName])["expiresAt"];
        return _e < new Date();
    };
    TokenObject.prototype.isTokenExist = function () {
        if (this.isTokenExpire()) {
            return false;
        }
        else {
            return localStorage[this.tokenName] !== undefined;
        }
    };
    TokenObject.prototype.setToken = function (value, expiresAt) {
        //{value: xxx, expiresAt: ttt}
        var json = { "value": value, "expiresAt": expiresAt };
        localStorage[this.tokenName] = JSON.stringify(json);
    };
    TokenObject.prototype.getToken = function () {
        if (this.isTokenExist()) {
            var _t = JSON.parse(localStorage[this.tokenName]);
            var token = _t["value"];
            var expiresAt = _t["expiresAt"];
            return { authToken: token, expireAt: expiresAt };
        }
        else {
            return { authToken: null, expireAt: null };
        }
    };
    TokenObject.prototype.removeToken = function () {
        localStorage.removeItem(this.tokenName);
    };
    return TokenObject;
}());

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/**
 * AuthProvider, Context provider that passes the auth down to the components
 * @param cookieName - Name of the auth Cookie. Default: '_authUser'
 * @param children - React.Component | React.FunctionalComponent
 * @constructor
 */
var AuthProvider = function (_a) {
    var cookieName = _a.cookieName, children = _a.children;
    var JWT_token = new TokenObject(cookieName);
    var _b = React.useState(JWT_token.getToken()), authObject = _b[0], setAuthObject = _b[1];
    React.useEffect(function () {
        if (authObject.authToken === undefined || authObject.authToken === null || authObject.expireAt === null) {
            JWT_token.removeToken();
        }
        else {
            JWT_token.setToken(authObject.authToken, authObject.expireAt);
        }
    }, [authObject]);
    return (React__default.createElement(React__default.Fragment, null,
        React__default.createElement(AuthContextProvider, { value: { authObject: authObject, setAuthToken: setAuthObject } }, children)));
};
AuthProvider.defaultProps = {
    cookieName: "_authUser"
};

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/**
 * Checks if the USER is logged in or not
 * @returns {{auth: boolean, authToken: string}} AuthObject
 */
var isAuth = function () {
    var value = React.useContext(AuthContext);
    if ((value === null || value === void 0 ? void 0 : value.authObject.authToken) && (value === null || value === void 0 ? void 0 : value.authObject.expireAt)) {
        if (value.authObject.expireAt < new Date()) {
            return { auth: true, authToken: value.authObject.authToken };
        }
        else {
            value.setAuthToken({ authToken: null, expireAt: null });
            return { auth: false, authToken: null };
        }
    }
    else {
        return { auth: false, authToken: null };
    }
};

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/**
 *
 * @param component - Component to
 * @param loginPath
 * @param path
 * @param rest
 * @constructor
 */
var PrivateRoute = function (_a) {
    var component = _a.component, loginPath = _a.loginPath, path = _a.path;
    var auth = isAuth().auth;
    if (auth) {
        return React__default.createElement(reactRouterDom.Route, { component: component, path: path });
    }
    else {
        return React__default.createElement(reactRouterDom.Redirect, { to: loginPath });
    }
};

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
/**
 * Auth Login function
 * @param token - Token from the backend server
 * @param expiresIn - Time takes to expires a token in minutes
 */
var loginAuth = function (token, expiresIn) {
    var expTime = new Date(new Date().getTime() + (expiresIn * 60 * 1000));
    try {
        var c = React.useContext(AuthContext);
        c === null || c === void 0 ? void 0 : c.setAuthToken({ authToken: token, expireAt: expTime });
        return true;
    }
    catch (e) {
        return false;
    }
};
/**
 * Auth Logout Function
 */
var logoutAuth = function () {
    try {
        var c = React.useContext(AuthContext);
        if (c === null || c === void 0 ? void 0 : c.authObject.authToken) {
            c.setAuthToken({ authToken: null, expireAt: null });
            return true;
        }
        else {
            return false;
        }
    }
    catch (e) {
        return false;
    }
};

/*
 * Copyright 2020. Arkadip Bhattacharya
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
var authHeader = function () {
    var c = React.useContext(AuthContext);
    if (c === null || c === void 0 ? void 0 : c.authObject.authToken) {
        return "Bearer " + c.authObject.authToken;
    }
    else {
        return null;
    }
};

exports.AuthProvider = AuthProvider;
exports.PrivateRoute = PrivateRoute;
exports.authHeader = authHeader;
exports.isAuth = isAuth;
exports.loginAuth = loginAuth;
exports.logoutAuth = logoutAuth;
